pub fn compare(
interp: &ExecutionSnapshot,
jit: &ExecutionSnapshot,
) -> Vec<Mismatch>Expand description
Compare two snapshots and return a list of mismatched fields.
pub fn compare(
interp: &ExecutionSnapshot,
jit: &ExecutionSnapshot,
) -> Vec<Mismatch>Compare two snapshots and return a list of mismatched fields.