pub fn run_interpreter(
cfg: &CfgEnv,
block: &BlockEnv,
tx: &TxEnv,
cache_state: &CacheState,
) -> ExecutionSnapshotExpand description
Run a single test case with the interpreter, returning an execution snapshot.
pub fn run_interpreter(
cfg: &CfgEnv,
block: &BlockEnv,
tx: &TxEnv,
cache_state: &CacheState,
) -> ExecutionSnapshotRun a single test case with the interpreter, returning an execution snapshot.