pub fn trace_interpreter(
cfg: &CfgEnv,
block: &BlockEnv,
tx: &TxEnv,
cache_state: &CacheState,
)Expand description
Re-run a test case with the interpreter and EIP-3155 tracing to stderr.
pub fn trace_interpreter(
cfg: &CfgEnv,
block: &BlockEnv,
tx: &TxEnv,
cache_state: &CacheState,
)Re-run a test case with the interpreter and EIP-3155 tracing to stderr.